==> panda_example_django-1.0.tar.gz: panda_example_django-1.0/panda_example_django/views.py <==
import os.path
from django.shortcuts import render_to_response
try:
    import json
except ImportError:
    import simplejson as json
from panda import Panda
import settings
from settings import PANDA_DETAILS as pd
import config

panda = Panda(api_host=pd['api_host'], cloud_id=pd['cloud_id'], secret_key=pd['secret_key'], access_key=pd['access_key'])

def index(request):
    access_details = panda.signed_params('POST', '/videos.json')
    access_details_json = json.dumps(access_details)
    return render_to_response('panda_example_django/index.html', {
        'panda_access_details': access_details_json,
        'panda_api_host': panda.api_host
    })

def player(request, panda_video_id):
    if os.path.isfile(os.path.join(config.PANDA_EXAMPLE_DJANGO_PLAYER_DIR, 'player.swf')):
        return _player(request, panda_video_id)
    else:
        return _player_missing(request)

def _player(request, panda_video_id):
    video_id = panda_video_id or request.GET.get('panda_video_id')
    panda_encodings = json.loads(panda.get("/videos/%s/encodings.json" % video_id))
    panda_encoding = panda_encodings[0]
    encoding = None;
    if panda_encoding['status'] == 'success':
        encoding = {
            'id'     : panda_encoding['id'],
            'url'    : "http://%s.s3.amazonaws.com/%s%s" % (settings.PANDA_S3_BUCKET, panda_encoding['id'], panda_encoding['extname']),
            'width'  : panda_encoding['width'],
            'height' : panda_encoding['height'],
        }
    return render_to_response('panda_example_django/player.html', {
        'panda_video_id': video_id,
        'panda_encodings_repr': repr(panda_encodings).replace(',', ',\n').replace('{', '\n{'),
        'encoding': encoding,
    })

def _player_missing(request):
    return render_to_response('panda_example_django/player_missing.html')

==> panda_example_django-1.1.tar.gz: panda_example_django-1.1/panda_example_django/views.py <==
import os.path
from django.shortcuts import render_to_response
try:
    import json
except ImportError:
    import simplejson as json
from panda import Panda
import settings
from settings import PANDA_DETAILS as pd
import config

panda = Panda(api_host=pd['api_host'], cloud_id=pd['cloud_id'], secret_key=pd['secret_key'], access_key=pd['access_key'])

def index(request):
    access_details = panda.signed_params('POST', '/videos.json')
    access_details_json = json.dumps(access_details)
    return render_to_response('panda_example_django/index.html', {
        'panda_access_details': access_details_json,
        'panda_api_host': panda.api_host
    })

def player(request, panda_video_id):
    video_id = panda_video_id or request.GET.get('panda_video_id')
    panda_encodings = json.loads(panda.get("/videos/%s/encodings.json" % video_id))
    encoding = None;
    for panda_encoding in panda_encodings:
        if panda_encoding['extname'] == '.mp4' and panda_encoding['status'] == 'success':
            encoding = {
                'id'     : panda_encoding['id'],
                'url'    : "http://%s.s3.amazonaws.com/%s%s" % (settings.PANDA_S3_BUCKET, panda_encoding['id'], panda_encoding['extname']),
                'width'  : panda_encoding['width'],
                'height' : panda_encoding['height'],
                'screenshot_url' : "http://%s.s3.amazonaws.com/%s_4.jpg" % (settings.PANDA_S3_BUCKET, panda_encoding['id']),
            }
    return render_to_response('panda_example_django/player.html', {
        'panda_video_id': video_id,
        'panda_encodings_repr': repr(panda_encodings).replace(',', ',\n').replace('{', '\n{'),
        'encoding': encoding,
    })
